@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Zircon/lib/RCS/Friends.tcl,v $
-# $Date: 1998/07/14 15:42:22 $
-# $Revision: 1.18.1.39 $
+# $Date: 1998/11/16 14:10:53 $
+# $Revision: 1.18.1.40 $
 #
 package provide zircon 1.18
 #
@@ -198,4 +198,8 @@ proc friends_flagState {this state} {
         }
     }
 }
+#
+proc Friends_cleanup {net where} {
+    foreach x [$net friends] { safeUnset ${where}$x }
+}
 
