@@ -1,7 +1,7 @@
 #
-# $Source: /home/nlfm/Zircon/lib/RCS/Netspace.tcl,v $
-# $Date: 1998/06/05 19:34:13 $
-# $Revision: 1.18.1.21 $
+# $Source: /home/nlfm/catless/Zircon/lib/RCS/Netspace.tcl,v $
+# $Date: 1998/10/08 09:37:48 $
+# $Revision: 1.18.1.22 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
@@ -119,6 +119,7 @@ proc nsUnload {name} {
 		setUnload $name disabled
 	    }
 	    delFromConf $name
+zshow "call $x delete"
 	    $x delete
 	    break
 	}
