@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Zircon/lib/RCS/main.tcl,v $
-# $Date: 1998/07/14 09:32:25 $
-# $Revision: 1.18.1.87 $
+# $Date: 1998/11/19 16:18:30 $
+# $Revision: 1.18.1.88 $
 #
 package provide zircon 1.18
 #
@@ -137,20 +137,29 @@ proc irc001 {net prefix param pargs} {
 }
 #
 proc irc004 {net prefix param pargs} {
-    set vers [lindex $pargs 2]
-    switch -glob -- $vers {
-    2.9* {
-	    $net configure -srvmsg 0
-	    [$net control] add2.9stuff
+zshow $pargs
+    set srvmsg 1
+    switch -regexp -- [set vers [lindex $pargs 2]] {
+    {^(2\.9|2.[1-9][0-9]+|[3-9]).*} {
+zshow $vers
+    	    set srvmsg 0
 	}
-    default {
+     u.* {
+     		$net configure -undernet 1
+	 }
+     dal.* {
+         }
+    }
+    if {$srvmsg} {
 	    set ctl [[$net control] window]
 	    if {[info exists $ctl.cr.srvmsg]} {
 		grid $w.srvmsg -row [[$this control] smrow] -column 3 -sticky ew
 	    }
 	    $net setFlag srvmsg
 	    [$net control] del2.9stuff
-	}
+    } {
+	    $net configure -srvmsg 0
+	    [$net control] add2.9stuff
     }
 
     $net configure -sVersion $vers \
