@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Zircon/lib/RCS/misc.tcl,v $
-# $Date: 1998/07/14 09:32:27 $
-# $Revision: 1.18.1.48 $
+# $Date: 1998/11/06 10:07:44 $
+# $Revision: 1.18.1.49 $
 #
 package provide zircon 1.18
 #
@@ -203,7 +203,7 @@ proc irc302 {net prefix param pargs} {
     elseif {[info exists fingerInfo($net)]} {
 	unset fingerInfo($net)
 	regexp {^~?([^@]*)@(.*)$} $uh match user host
-	if {![catch {connect $host 79} sock]} {
+	if {![catch {$net connect $host 79} sock]} {
 		set w .@[newName fng]
 		fileevent $sock readable "handleFinger $net $sock $w"
 		makeToplevel $w "Finger [$usr name]" "
@@ -437,7 +437,7 @@ proc handleURL {net url} {
 		exec netscape $url &
 	    }
 	} \
-	elseif {[catch {connect localhost $zircon(cciport)} ccisock]} {
+	elseif {[catch {$net connect localhost $zircon(cciport)} ccisock]} {
 	    $net errmsg "Cannot connect to WWW viewer ($val)"
 	} {
 	    set url [string trim $url]
